==============================
Stallings Graphs Research Code
==============================

This is the reference manual for `Pascal Weil <http://www.labri.fr/perso/weil/>`_'s  ``stallings_graphs`` Research Code extension to the `Sage <http://sagemath.org/>`_ mathematical software system.  Sage is free open source math software that supports research and teaching in algebra, geometry, number theory, cryptography, and related areas.  


.. include:: ../README.rst


Finitely generated subgroups of free groups
===========================================

.. toctree::
   :maxdepth: 2
   
   finitely_generated_subgroup
   about_words
   about_automata
   about_folding
   about_bases
   about_TC_morphisms
   about_free_factors


Partial injections
==================

.. toctree::
   :maxdepth: 2
   
   partial_injections
   partial_injections_misc




References, Indices and tables
==============================

.. [BNW2008] F. Bassino, C. Nicaud, P. Weil. Random generation of finitely generated subgroups of a free group, *International Journal of Algebra and Computation* **18** (2008) 1-31.

.. [MVW2007] A. Miasnikov, E. Ventura, P. Weil. Algebraic extensions in free groups, in (G.N. Arzhantseva, L. Bartholdi, J. Burillo, E. Ventura eds.) *Geometric group theory, Geneva and Barcelona conferences, Trends in Mathematics, Birkhaüser* (2007), pp. 225-253. 

.. [SW2008] P. Silva, P. Weil. On an algorithm to decide whether a free group is a free factor of another, *Theoretical Informatics and Applications* **42** (2008) 395-414.

.. [T2006] N. Touikan, A Fast Algorithm for Stallings' Folding Process, *International Journal of Algebra and Computation* **16** 2006 1031-1045.


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
